@@ -12,6 +12,10 @@ from .entity import (
     DatapipeServerInfo,
     FileTemplateVariables,
     FilesTemplateVariables,
+    InstanceCreationItem,
+    InstanceCreationRequest,
+    InstanceInfo,
+    InstanceUserSetting,
     NodeInventory,
     ProxyInfo,
     RandomTemplateVariables,
@@ -36,6 +40,10 @@ from .dto import (
     DatapipeServerInfoDTO,
     FileTemplateVariablesDTO,
     FilesTemplateVariablesDTO,
+    InstanceCreationItemDTO,
+    InstanceCreationRequestDTO,
+    InstanceInfoDTO,
+    InstanceUserSettingDTO,
     NodeInventoryDTO,
     ProxyInfoDTO,
     RandomTemplateVariablesDTO,
@@ -51,8 +59,10 @@ from .dto import (
 from .value_obj import (
     K3SNodeType,
     Status,
+    UBool,
     UDate,
     UDict,
+    UFloat,
     UInt,
     UStr
 )
@@ -524,3 +534,143 @@ class ProxyInfoAssembler(Assembler):
             auth = None if x.auth is None else x.auth.get_value()
         )
 proxy_info_assembler=ProxyInfoAssembler()
+
+
+
+class InstanceUserSettingAssembler(Assembler):
+    def to_entity(self, dto: InstanceUserSettingDTO):
+        return InstanceUserSetting(
+            name = UStr(dto.name),
+            region_id = UStr(dto.region_id),
+            image_id = None if dto.image_id is None else UStr(dto.image_id),
+            internet_pay_type = None if dto.internet_pay_type is None else UStr(dto.internet_pay_type),
+            key_name = UStr(dto.key_name),
+            password = UStr(dto.password),
+            amount = UStr(dto.amount),
+            bandwidth_in = UInt(dto.bandwidth_in),
+            bandwidth_out = UInt(dto.bandwidth_out),
+            user_data = None if dto.user_data is None else UStr(dto.user_data),
+            disk_size = UInt(dto.disk_size),
+            exclude_instance_types = [UStr(m) for m in dto.exclude_instance_types],
+            inner_connection = UBool(dto.inner_connection)
+        )
+    def to_dto(self, x:InstanceUserSetting):
+        return InstanceUserSettingDTO(
+            name = x.name.get_value(),
+            region_id = x.region_id.get_value(),
+            image_id = None if x.image_id is None else x.image_id.get_value(),
+            internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
+            key_name = x.key_name.get_value(),
+            password = x.password.get_value(),
+            amount = x.amount.get_value(),
+            bandwidth_in = x.bandwidth_in.get_value(),
+            bandwidth_out = x.bandwidth_out.get_value(),
+            user_data = None if x.user_data is None else x.user_data.get_value(),
+            disk_size = x.disk_size.get_value(),
+            exclude_instance_types = [m.get_value() for m in x.exclude_instance_types],
+            inner_connection = x.inner_connection.get_value()
+        )
+instance_user_setting_assembler=InstanceUserSettingAssembler()
+
+
+
+class InstanceCreationRequestAssembler(Assembler):
+    def to_entity(self, dto: InstanceCreationRequestDTO):
+        return InstanceCreationRequest(
+            instance_user_setting = instance_user_setting_assembler.to_entity(dto.instance_user_setting),
+            condition = condition_assembler.to_entity(dto.condition),
+            priority = UInt(dto.priority),
+            timeout = UInt(dto.timeout)
+        )
+    def to_dto(self, x:InstanceCreationRequest):
+        return InstanceCreationRequestDTO(
+            instance_user_setting = instance_user_setting_assembler.to_dto(x.instance_user_setting),
+            condition = condition_assembler.to_dto(x.condition),
+            priority = x.priority.get_value(),
+            timeout = x.timeout.get_value()
+        )
+instance_creation_request_assembler=InstanceCreationRequestAssembler()
+
+
+
+class InstanceInfoAssembler(Assembler):
+    def to_entity(self, dto: InstanceInfoDTO):
+        return InstanceInfo(
+            id = UStr(dto.id),
+            instance_type = UStr(dto.instance_type),
+            create_time = UDate(dto.create_time),
+            name = UStr(dto.name),
+            hostname = UStr(dto.hostname),
+            pay_type = UStr(dto.pay_type),
+            public_ip = [UStr(m) for m in dto.public_ip],
+            private_ip = None if dto.private_ip is None else UStr(dto.private_ip),
+            os_name = UStr(dto.os_name),
+            price = UFloat(dto.price),
+            image_id = UStr(dto.image_id),
+            region_id = UStr(dto.region_id),
+            zone_id = UStr(dto.zone_id),
+            internet_pay_type = UStr(dto.internet_pay_type),
+            bandwidth_in = UStr(dto.bandwidth_in),
+            bandwidth_out = UStr(dto.bandwidth_out),
+            status = UStr(dto.status),
+            key_name = UStr(dto.key_name),
+            security_group_id = [UStr(m) for m in dto.security_group_id],
+            instance_expired_time = None if dto.instance_expired_time is None else UStr(dto.instance_expired_time),
+            auto_release_time = None if dto.auto_release_time is None else UStr(dto.auto_release_time),
+            _life_time = UInt(dto._life_time)
+        )
+    def to_dto(self, x:InstanceInfo):
+        return InstanceInfoDTO(
+            id = x.id.get_value(),
+            instance_type = x.instance_type.get_value(),
+            create_time = x.create_time.get_value(),
+            name = x.name.get_value(),
+            hostname = x.hostname.get_value(),
+            pay_type = x.pay_type.get_value(),
+            public_ip = [m.get_value() for m in x.public_ip],
+            private_ip = None if x.private_ip is None else x.private_ip.get_value(),
+            os_name = x.os_name.get_value(),
+            price = x.price.get_value(),
+            image_id = x.image_id.get_value(),
+            region_id = x.region_id.get_value(),
+            zone_id = x.zone_id.get_value(),
+            internet_pay_type = x.internet_pay_type.get_value(),
+            bandwidth_in = x.bandwidth_in.get_value(),
+            bandwidth_out = x.bandwidth_out.get_value(),
+            status = x.status.get_value(),
+            key_name = x.key_name.get_value(),
+            security_group_id = [m.get_value() for m in x.security_group_id],
+            instance_expired_time = None if x.instance_expired_time is None else x.instance_expired_time.get_value(),
+            auto_release_time = None if x.auto_release_time is None else x.auto_release_time.get_value(),
+            _life_time = x._life_time.get_value()
+        )
+instance_info_assembler=InstanceInfoAssembler()
+
+
+
+class InstanceCreationItemAssembler(Assembler):
+    def to_entity(self, dto: InstanceCreationItemDTO):
+        return InstanceCreationItem(
+            id = UStr(dto.id),
+            instance_creation_request = None if dto.instance_creation_request is None else instance_creation_request_assembler.to_entity(dto.instance_creation_request),
+            status = UStr(dto.status),
+            creation_time = UDate(dto.creation_time),
+            details = None if dto.details is None else [instance_info_assembler.to_entity(m) for m in dto.details],
+            entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
+            exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
+            exception = None if dto.exception is None else UStr(dto.exception),
+            _life_time = UStr(dto._life_time)
+        )
+    def to_dto(self, x:InstanceCreationItem):
+        return InstanceCreationItemDTO(
+            id = x.id.get_value(),
+            instance_creation_request = None if x.instance_creation_request is None else instance_creation_request_assembler.to_dto(x.instance_creation_request),
+            status = x.status.get_value(),
+            creation_time = x.creation_time.get_value(),
+            details = None if x.details is None else [instance_info_assembler.to_dto(m) for m in x.details],
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            _life_time = x._life_time.get_value()
+        )
+instance_creation_item_assembler=InstanceCreationItemAssembler()
