@@ -12,6 +12,10 @@ from .entity import (
     DatapipeServerInfo,
     FileTemplateVariables,
     FilesTemplateVariables,
+    InstanceCreationItem,
+    InstanceCreationRequest,
+    InstanceInfo,
+    InstanceUserSetting,
     NodeInventory,
     ProxyInfo,
     RandomTemplateVariables,
@@ -36,6 +40,10 @@ from .do import (
     DatapipeServerInfoDO,
     FileTemplateVariablesDO,
     FilesTemplateVariablesDO,
+    InstanceCreationItemDO,
+    InstanceCreationRequestDO,
+    InstanceInfoDO,
+    InstanceUserSettingDO,
     NodeInventoryDO,
     ProxyInfoDO,
     RandomTemplateVariablesDO,
@@ -51,8 +59,10 @@ from .do import (
 from .value_obj import (
     K3SNodeType,
     Status,
+    UBool,
     UDate,
     UDict,
+    UFloat,
     UInt,
     UStr
 )
@@ -524,3 +534,143 @@ class ProxyInfoConverter(Converter):
             auth = None if x.auth is None else x.auth.get_value()
         )
 proxy_info_converter=ProxyInfoConverter()
+
+
+
+class InstanceUserSettingConverter(Converter):
+    def to_entity(self, do: InstanceUserSettingDO):
+        return InstanceUserSetting(
+            name = UStr(do.name),
+            region_id = UStr(do.region_id),
+            image_id = None if do.image_id is None else UStr(do.image_id),
+            internet_pay_type = None if do.internet_pay_type is None else UStr(do.internet_pay_type),
+            key_name = UStr(do.key_name),
+            password = UStr(do.password),
+            amount = UStr(do.amount),
+            bandwidth_in = UInt(do.bandwidth_in),
+            bandwidth_out = UInt(do.bandwidth_out),
+            user_data = None if do.user_data is None else UStr(do.user_data),
+            disk_size = UInt(do.disk_size),
+            exclude_instance_types = [UStr(m) for m in do.exclude_instance_types],
+            inner_connection = UBool(do.inner_connection)
+        )
+    def to_do(self, x:InstanceUserSetting):
+        return InstanceUserSettingDO(
+            name = x.name.get_value(),
+            region_id = x.region_id.get_value(),
+            image_id = None if x.image_id is None else x.image_id.get_value(),
+            internet_pay_type = None if x.internet_pay_type is None else x.internet_pay_type.get_value(),
+            key_name = x.key_name.get_value(),
+            password = x.password.get_value(),
+            amount = x.amount.get_value(),
+            bandwidth_in = x.bandwidth_in.get_value(),
+            bandwidth_out = x.bandwidth_out.get_value(),
+            user_data = None if x.user_data is None else x.user_data.get_value(),
+            disk_size = x.disk_size.get_value(),
+            exclude_instance_types = [m.get_value() for m in x.exclude_instance_types],
+            inner_connection = x.inner_connection.get_value()
+        )
+instance_user_setting_converter=InstanceUserSettingConverter()
+
+
+
+class InstanceCreationRequestConverter(Converter):
+    def to_entity(self, do: InstanceCreationRequestDO):
+        return InstanceCreationRequest(
+            instance_user_setting = instance_user_setting_converter.to_entity(do.instance_user_setting),
+            condition = condition_converter.to_entity(do.condition),
+            priority = UInt(do.priority),
+            timeout = UInt(do.timeout)
+        )
+    def to_do(self, x:InstanceCreationRequest):
+        return InstanceCreationRequestDO(
+            instance_user_setting = instance_user_setting_converter.to_do(x.instance_user_setting),
+            condition = condition_converter.to_do(x.condition),
+            priority = x.priority.get_value(),
+            timeout = x.timeout.get_value()
+        )
+instance_creation_request_converter=InstanceCreationRequestConverter()
+
+
+
+class InstanceInfoConverter(Converter):
+    def to_entity(self, do: InstanceInfoDO):
+        return InstanceInfo(
+            id = UStr(do.id),
+            instance_type = UStr(do.instance_type),
+            create_time = UDate(do.create_time),
+            name = UStr(do.name),
+            hostname = UStr(do.hostname),
+            pay_type = UStr(do.pay_type),
+            public_ip = [UStr(m) for m in do.public_ip],
+            private_ip = None if do.private_ip is None else UStr(do.private_ip),
+            os_name = UStr(do.os_name),
+            price = UFloat(do.price),
+            image_id = UStr(do.image_id),
+            region_id = UStr(do.region_id),
+            zone_id = UStr(do.zone_id),
+            internet_pay_type = UStr(do.internet_pay_type),
+            bandwidth_in = UStr(do.bandwidth_in),
+            bandwidth_out = UStr(do.bandwidth_out),
+            status = UStr(do.status),
+            key_name = UStr(do.key_name),
+            security_group_id = [UStr(m) for m in do.security_group_id],
+            instance_expired_time = None if do.instance_expired_time is None else UStr(do.instance_expired_time),
+            auto_release_time = None if do.auto_release_time is None else UStr(do.auto_release_time),
+            _life_time = UInt(do._life_time)
+        )
+    def to_do(self, x:InstanceInfo):
+        return InstanceInfoDO(
+            id = x.id.get_value(),
+            instance_type = x.instance_type.get_value(),
+            create_time = x.create_time.get_value(),
+            name = x.name.get_value(),
+            hostname = x.hostname.get_value(),
+            pay_type = x.pay_type.get_value(),
+            public_ip = [m.get_value() for m in x.public_ip],
+            private_ip = None if x.private_ip is None else x.private_ip.get_value(),
+            os_name = x.os_name.get_value(),
+            price = x.price.get_value(),
+            image_id = x.image_id.get_value(),
+            region_id = x.region_id.get_value(),
+            zone_id = x.zone_id.get_value(),
+            internet_pay_type = x.internet_pay_type.get_value(),
+            bandwidth_in = x.bandwidth_in.get_value(),
+            bandwidth_out = x.bandwidth_out.get_value(),
+            status = x.status.get_value(),
+            key_name = x.key_name.get_value(),
+            security_group_id = [m.get_value() for m in x.security_group_id],
+            instance_expired_time = None if x.instance_expired_time is None else x.instance_expired_time.get_value(),
+            auto_release_time = None if x.auto_release_time is None else x.auto_release_time.get_value(),
+            _life_time = x._life_time.get_value()
+        )
+instance_info_converter=InstanceInfoConverter()
+
+
+
+class InstanceCreationItemConverter(Converter):
+    def to_entity(self, do: InstanceCreationItemDO):
+        return InstanceCreationItem(
+            id = UStr(do.id),
+            instance_creation_request = None if do.instance_creation_request is None else instance_creation_request_converter.to_entity(do.instance_creation_request),
+            status = UStr(do.status),
+            creation_time = UDate(do.creation_time),
+            details = None if do.details is None else [instance_info_converter.to_entity(m) for m in do.details],
+            entry_time = None if do.entry_time is None else UDate(do.entry_time),
+            exit_time = None if do.exit_time is None else UDate(do.exit_time),
+            exception = None if do.exception is None else UStr(do.exception),
+            _life_time = UStr(do._life_time)
+        )
+    def to_do(self, x:InstanceCreationItem):
+        return InstanceCreationItemDO(
+            id = x.id.get_value(),
+            instance_creation_request = None if x.instance_creation_request is None else instance_creation_request_converter.to_do(x.instance_creation_request),
+            status = x.status.get_value(),
+            creation_time = x.creation_time.get_value(),
+            details = None if x.details is None else [instance_info_converter.to_do(m) for m in x.details],
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            _life_time = x._life_time.get_value()
+        )
+instance_creation_item_converter=InstanceCreationItemConverter()
