@@ -170,7 +170,7 @@ class RecoverSettingDO(BaseModel):
 class SearchRequestDO(BaseModel):
     keyword: str
     limit: int = 5
-    timeout: int = '300'
+    timeout: int = 300
     request_id: Optional[str] = None
     others: Optional[dict] = None
 
@@ -201,4 +201,68 @@ class ProxyInfoDO(BaseModel):
     ip: str
     port: int
     protocol: str
-    auth: Optional[dict] = None
\ No newline at end of file
+    auth: Optional[dict] = None
+
+
+
+class InstanceUserSettingDO(BaseModel):
+    name: str
+    region_id: str
+    image_id: Optional[str]
+    internet_pay_type: Optional[str]
+    key_name: str
+    password: str = '1234Abcd'
+    amount: str = 1
+    bandwidth_in: int = 200
+    bandwidth_out: int = 1
+    user_data: Optional[str] = None
+    disk_size: int = 20
+    exclude_instance_types: List[str] = []
+    inner_connection: bool = True
+
+
+
+class InstanceCreationRequestDO(BaseModel):
+    instance_user_setting: InstanceUserSettingDO
+    condition: ConditionDO
+    priority: int = 3
+    timeout: int = 400
+
+
+
+class InstanceInfoDO(BaseModel):
+    id: str
+    instance_type: str
+    create_time: datetime.datetime
+    name: str
+    hostname: str
+    pay_type: str
+    public_ip: List[str]
+    private_ip: Optional[str]
+    os_name: str
+    price: float
+    image_id: str
+    region_id: str
+    zone_id: str
+    internet_pay_type: str
+    bandwidth_in: str
+    bandwidth_out: str
+    status: str
+    key_name: str
+    security_group_id: List[str]
+    instance_expired_time: Optional[str]
+    auto_release_time: Optional[str]
+    _life_time: int = 5
+
+
+
+class InstanceCreationItemDO(BaseModel):
+    id: str
+    instance_creation_request: Optional[InstanceCreationRequestDO]
+    status: str
+    creation_time: datetime.datetime
+    details: Optional[List[InstanceInfoDO]] = None
+    entry_time: Optional[datetime.datetime] = None
+    exit_time: Optional[datetime.datetime] = None
+    exception: Optional[str] = None
+    _life_time: str = 86400
\ No newline at end of file
