@@ -4,8 +4,10 @@ from ..domain.entity import Entity
 from .value_obj import (
     K3SNodeType,
     Status,
+    UBool,
     UDate,
     UDict,
+    UFloat,
     UInt,
     UStr
 )
@@ -15,10 +17,10 @@ from .value_obj import (
 class Condition(Entity):
     def __init__(
         self,
-        min_cpu_num: Optional[UInt] = 1,
-        max_cpu_num: Optional[UInt] = 1,
-        min_memory_size: Optional[UInt] = 1,
-        max_memory_size: Optional[UInt] = 1,
+        min_cpu_num: Optional[UInt] = UInt(1),
+        max_cpu_num: Optional[UInt] = UInt(1),
+        min_memory_size: Optional[UInt] = UInt(1),
+        max_memory_size: Optional[UInt] = UInt(1),
         min_gpu_num: Optional[UInt] = None,
         max_gpu_num: Optional[UInt] = None,
         min_gpu_memory_size: Optional[UInt] = None,
@@ -66,7 +68,7 @@ class DatapipeDataInfo(Entity):
         bucket: UStr,
         remote_path: UStr,
         local_path: UStr,
-        timeout: UInt = 3,
+        timeout: UInt = UInt(3),
         **kwargs
     ) -> None:
         all_args=locals()
@@ -105,7 +107,7 @@ class ClusterConfig(Entity):
         region_id: UStr,
         config_data: Optional[ClusterConfigData] = None,
         entry_point: Optional[List[UStr]] = None,
-        timeout: UInt = 20,
+        timeout: UInt = UInt(20),
         **kwargs
     ) -> None:
         all_args=locals()
@@ -125,8 +127,8 @@ class BootstrapInfo(Entity):
     def __init__(
         self,
         cluster_config: ClusterConfig,
-        template: UStr = 'normal',
-        platform: UStr = 'aliyun',
+        template: UStr = UStr('normal'),
+        platform: UStr = UStr('aliyun'),
         patch_setting: Optional[UDict] = None,
         **kwargs
     ) -> None:
@@ -251,21 +253,21 @@ class TaskRequest(Entity):
         condition: Condition,
         git_url: Optional[UStr],
         git_branch: Optional[UStr],
-        task_type: Optional[UStr] = 'cluster',
+        task_type: Optional[UStr] = UStr('cluster'),
         task_template: Optional[UStr] = None,
         task_env: Optional[UDict] = None,
-        task_command: Optional[List[UStr]] = ['sleep', '100000'],
+        task_command: Optional[List[UStr]] = [UStr('sleep'),UStr('100000')],
         task_arg: Optional[List[UStr]] = None,
         task_working_dir: Optional[UStr] = None,
-        task_image: Optional[UStr] = 'alpine:3.12',
+        task_image: Optional[UStr] = UStr('alpine:3.12'),
         task_start_time: Optional[UStr] = None,
-        priority: UInt = 3,
-        amount: UInt = 1,
+        priority: UInt = UInt(3),
+        amount: UInt = UInt(1),
         duration: Optional[UInt] = None,
-        disk_size: Optional[UInt] = 20,
-        end_style: UStr = 'delete',
-        restart_policy: UStr = 'never',
-        timeout: UInt = 500,
+        disk_size: Optional[UInt] = UInt(20),
+        end_style: UStr = UStr('delete'),
+        restart_policy: UStr = UStr('never'),
+        timeout: UInt = UInt(500),
         cluster_name: Optional[UStr] = None,
         **kwargs
     ) -> None:
@@ -432,8 +434,8 @@ class SearchRequest(Entity):
     def __init__(
         self,
         keyword: UStr,
-        limit: UInt = 5,
-        timeout: UInt = '300',
+        limit: UInt = UInt(5),
+        timeout: UInt = UInt(300),
         request_id: Optional[UStr] = None,
         others: Optional[UDict] = None,
         **kwargs
@@ -483,7 +485,7 @@ class SearchItem(Entity):
         entry_time: Optional[UDate] = None,
         exit_time: Optional[UDate] = None,
         create_time: Optional[UDate] = None,
-        failure_times: UInt = 0,
+        failure_times: UInt = UInt(0),
         **kwargs
     ) -> None:
         all_args=locals()
@@ -520,4 +522,152 @@ class ProxyInfo(Entity):
         self.ip = ip
         self.port = port
         self.protocol = protocol
-        self.auth = auth
\ No newline at end of file
+        self.auth = auth
+
+
+
+class InstanceUserSetting(Entity):
+    def __init__(
+        self,
+        name: UStr,
+        region_id: UStr,
+        image_id: Optional[UStr],
+        internet_pay_type: Optional[UStr],
+        key_name: UStr,
+        password: UStr = UStr('1234Abcd'),
+        amount: UStr = UStr('1'),
+        bandwidth_in: UInt = UInt(200),
+        bandwidth_out: UInt = UInt(1),
+        user_data: Optional[UStr] = None,
+        disk_size: UInt = UInt(20),
+        exclude_instance_types: List[UStr] = [],
+        inner_connection: UBool = UBool(True),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.name = name
+        self.region_id = region_id
+        self.image_id = image_id
+        self.internet_pay_type = internet_pay_type
+        self.key_name = key_name
+        self.password = password
+        self.amount = amount
+        self.bandwidth_in = bandwidth_in
+        self.bandwidth_out = bandwidth_out
+        self.user_data = user_data
+        self.disk_size = disk_size
+        self.exclude_instance_types = exclude_instance_types
+        self.inner_connection = inner_connection
+
+
+
+class InstanceCreationRequest(Entity):
+    def __init__(
+        self,
+        instance_user_setting: InstanceUserSetting,
+        condition: Condition,
+        priority: UInt = UInt(3),
+        timeout: UInt = UInt(400),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.instance_user_setting = instance_user_setting
+        self.condition = condition
+        self.priority = priority
+        self.timeout = timeout
+
+
+
+class InstanceInfo(Entity):
+    def __init__(
+        self,
+        id: UStr,
+        instance_type: UStr,
+        create_time: UDate,
+        name: UStr,
+        hostname: UStr,
+        pay_type: UStr,
+        public_ip: List[UStr],
+        private_ip: Optional[UStr],
+        os_name: UStr,
+        price: UFloat,
+        image_id: UStr,
+        region_id: UStr,
+        zone_id: UStr,
+        internet_pay_type: UStr,
+        bandwidth_in: UStr,
+        bandwidth_out: UStr,
+        status: UStr,
+        key_name: UStr,
+        security_group_id: List[UStr],
+        instance_expired_time: Optional[UStr],
+        auto_release_time: Optional[UStr],
+        _life_time: UInt = UInt(5),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.id = id
+        self.instance_type = instance_type
+        self.create_time = create_time
+        self.name = name
+        self.hostname = hostname
+        self.pay_type = pay_type
+        self.public_ip = public_ip
+        self.private_ip = private_ip
+        self.os_name = os_name
+        self.price = price
+        self.image_id = image_id
+        self.region_id = region_id
+        self.zone_id = zone_id
+        self.internet_pay_type = internet_pay_type
+        self.bandwidth_in = bandwidth_in
+        self.bandwidth_out = bandwidth_out
+        self.status = status
+        self.key_name = key_name
+        self.security_group_id = security_group_id
+        self.instance_expired_time = instance_expired_time
+        self.auto_release_time = auto_release_time
+        self._life_time = _life_time
+
+
+
+class InstanceCreationItem(Entity):
+    def __init__(
+        self,
+        id: UStr,
+        instance_creation_request: Optional[InstanceCreationRequest],
+        status: UStr,
+        creation_time: UDate,
+        details: Optional[List[InstanceInfo]] = None,
+        entry_time: Optional[UDate] = None,
+        exit_time: Optional[UDate] = None,
+        exception: Optional[UStr] = None,
+        _life_time: UStr = UStr('86400'),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.id = id
+        self.instance_creation_request = instance_creation_request
+        self.status = status
+        self.creation_time = creation_time
+        self.details = details
+        self.entry_time = entry_time
+        self.exit_time = exit_time
+        self.exception = exception
+        self._life_time = _life_time
\ No newline at end of file
